==> haskell-unicode-show-0.1.0.3-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.3
id: unicode-show-0.1.0.3-CotN7zxqeHFDHCw3hquS7M
key: unicode-show-0.1.0.3-CotN7zxqeHFDHCw3hquS7M
license: BSD-3-Clause
copyright: 2016 Takayuki Muranushi
maintainer: whosekiteneverfly@gmail.com
author: Takayuki Muranushi
homepage: http://github.com/haskell-jp/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
abi: 124057547abbd0635ebbebedf9eb53fa
exposed: True
exposed-modules:
    Text.Show.Unicode
import-dirs: /usr/lib/ghc-8.4.3/site-local/unicode-show-0.1.0.3
library-dirs: /usr/lib/ghc-8.4.3/site-local/unicode-show-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/unicode-show-0.1.0.3
hs-libraries: HSunicode-show-0.1.0.3-CotN7zxqeHFDHCw3hquS7M
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unicode-show-0.1.0.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-unicode-show.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: unicode-show
version: 0.1.0.3
id: unicode-show-0.1.0.3-E42BjzqrCwr19xsyZVjnik
key: unicode-show-0.1.0.3-E42BjzqrCwr19xsyZVjnik
license: BSD-3-Clause
copyright: 2016 Takayuki Muranushi
maintainer: whosekiteneverfly@gmail.com
author: Takayuki Muranushi
homepage: http://github.com/haskell-jp/unicode-show#readme
synopsis: print and show in unicode
description:
    This package provides variants of '\''show'\'' and '\''print'\'' functions that does not escape non-ascii characters.
    .
    See <http://github.com/haskell-jp/unicode-show#readme README> for usage.
    .
    Run ghci with  @-interactive-print@ flag to print unicode characters. See <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/interactive-evaluation.html#ghci-interactive-print Using a custom interactive printing function> section in the GHC manual.
category: Text
abi: 774bb6ec9d014e259a2b1aea450178db
exposed: True
exposed-modules:
    Text.Show.Unicode
import-dirs: /usr/lib/ghc-8.6.1/site-local/unicode-show-0.1.0.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/unicode-show-0.1.0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/unicode-show-0.1.0.3
hs-libraries: HSunicode-show-0.1.0.3-E42BjzqrCwr19xsyZVjnik
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-unicode-show/html/unicode-show.haddock
haddock-html: /usr/share/doc/haskell-unicode-show/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
